@@ -2,6 +2,7 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 import sys
+import warnings
 
 from natsort.natsort import (
     as_ascii,
@@ -25,7 +26,7 @@ from natsort.utils import chain_functions
 if float(sys.version[:3]) < 3:
     from natsort.natsort import natcmp
 
-__version__ = "5.4.1"
+__version__ = "5.5.0"
 
 __all__ = [
     "natsort_key",
@@ -49,4 +50,8 @@ __all__ = [
 
 # Add the ns keys to this namespace for convenience.
 # A dict comprehension is not used for Python 2.6 compatibility.
-globals().update(dict((k, getattr(ns, k)) for k in dir(ns) if k.isupper()))
+# We catch warnings from the deprecated ns enum values when adding
+# them to natsort's main namespace.
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore")
+    globals().update(dict((k, getattr(ns, k)) for k in dir(ns) if k.isupper()))
